==> scwm_0.8a.orig.tar.gz: scwm-0.8a/scheme/image-loaders.scm <==
;;;; 	Copyright (C) 1998 Maciej Stachowiak
;;;; 
;;;; This program is free software; you can redistribute it and/or modify
;;;; it under the terms of the GNU General Public License as published by
;;;; the Free Software Foundation; either version 2, or (at your option)
;;;; any later version.
;;;; 
;;;; This program is distributed in the hope that it will be useful,
;;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;;; GNU General Public License for more details.
;;;; 
;;;; You should have received a copy of the GNU General Public License
;;;; along with this software; see the file COPYING.  If not, write to
;;;; the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
;;;; Boston, MA 02111-1307 USA
;;;; 



(define-module (app scwm image-loaders))



;; Uses the "convert" tool from the ImageMagick package to try to
;; convert the file to an xpm, then attempts to load it as such.
(define-public (ImageMagick-loader fname)
  (let ((t (string-append (tmpnam) ".xpm")))
    (catch #t
	   (lambda () (system (string-append "convert " fname " " t)))
	   (lambda args #f))
    (load-xpm t)))

;; Uses the "anytopnm" and "ppmtoxpm" tools from the netpbm package to
;; try to convert the file to an xpm, then attempts to load it as
;; such.
(define-public (netpbm-loader fname)
  (let ((t (string-append (tmpnam) ".xpm")))
    (catch #t
	   (lambda () 
	     (system (string-append "anytopnm " fname " | ppmtoxpm > " t)))
	   (lambda args #f))
    (load-xpm t)))

;; Try all available loaders.
(define-public (try-everything-loader fname)
  (cond
   ((ImageMagick-loader fname) => id)
   (else (netpbm-loader fname))))

;; Just a convenience wrapper to make the try-everything-loader
;; the default.
(define-public (support-image-conversion)
  (register-image-loader "default" try-everything-loader))

==> scwm_0.99.6.1.orig.tar.gz: scwm-0.99.6.1/scheme/image-loaders.scm <==
;;;; $Id: image-loaders.scm,v 1.5 1999/04/12 00:57:10 jtl Exp $
;;;; Copyright (C) 1998 Maciej Stachowiak and Greg J. Badros
;;;; 
;;;; This program is free software; you can redistribute it and/or modify
;;;; it under the terms of the GNU General Public License as published by
;;;; the Free Software Foundation; either version 2, or (at your option)
;;;; any later version.
;;;; 
;;;; This program is distributed in the hope that it will be useful,
;;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;;; GNU General Public License for more details.
;;;; 
;;;; You should have received a copy of the GNU General Public License
;;;; along with this software; see the file COPYING.  If not, write to
;;;; the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
;;;; Boston, MA 02111-1307 USA
;;;; 



(define-module (app scwm image-loaders))



;; CRW:FIXME:: We should delete these temporary files at some point...

(define-public (ImageMagick-loader fname)
  "Tries to load an arbitrary image using ImageMagick's `convert'.
Uses `convert' to try to convert the file to an xpm, then
attempts to load it as such."
  (let ((t (string-append (tmpnam) ".xpm")))
    (catch #t
	   (lambda () (system (string-append "convert " fname " " t)))
	   (lambda args #f))
    (load-xpm t)))

(define-public (netpbm-loader fname)
  "Tries to load an arbitrary image using the netpbm packge.
Uses `anytoppm' and `ppmtoxpm' to try to convert the file to an xpm,
then attempts to load it as such."
  (let ((t (string-append (tmpnam) ".xpm")))
    (catch #t
	   (lambda () 
	     (system (string-append "anytopnm " fname " | ppmtoxpm > " t)))
	   (lambda args #f))
    (load-xpm t)))

(define-public (try-everything-loader fname)
  "Tries to load an arbitrary image, using any available loader."
  (cond
   ((ImageMagick-loader fname) => id)
   (else (netpbm-loader fname))))

(define-public (support-image-conversion)
  "Set things up to try to load arbitrary images.
Works by setting `try-everything-loader' as the image loader for
unknown extensions.  Generally not needed with ImLib."
  (if (not (defined? 'load-imlib-image))
      (register-image-loader "default" try-everything-loader)))
